@@ -498,8 +498,12 @@ class Item(gtk.HBox, Draggable):
             if self.subject.uri.startswith("http"):
                 self.icon = self.content_obj.get_actor_pixbuf(24)
             else:
-                self.icon = self.content_obj.get_icon(
-                    can_thumb=settings.get('small_thumbnails', False), border=0)          
+                if settings:
+                    self.icon = self.content_obj.get_icon(
+                        can_thumb=settings.get('small_thumbnails', False), border=0)          
+                else:
+                    self.icon = self.content_obj.get_icon(
+                        can_thumb=False, border=0)          
         else:
             self.icon = None
         self.btn.set_relief(gtk.RELIEF_NONE)
